==> zio-aws-rds_3-5.17.129.1-sources.jar: zio/aws/rds/model/CopyDbClusterParameterGroupRequest.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CopyDbClusterParameterGroupRequest(
    sourceDBClusterParameterGroupIdentifier: String,
    targetDBClusterParameterGroupIdentifier: String,
    targetDBClusterParameterGroupDescription: String,
    tags: scala.Option[Iterable[zio.aws.rds.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest = {
    import CopyDbClusterParameterGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
      .builder()
      .sourceDBClusterParameterGroupIdentifier(
        sourceDBClusterParameterGroupIdentifier: java.lang.String
      )
      .targetDBClusterParameterGroupIdentifier(
        targetDBClusterParameterGroupIdentifier: java.lang.String
      )
      .targetDBClusterParameterGroupDescription(
        targetDBClusterParameterGroupDescription: java.lang.String
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.CopyDbClusterParameterGroupRequest.ReadOnly =
    zio.aws.rds.model.CopyDbClusterParameterGroupRequest.wrap(buildAwsValue())
}
object CopyDbClusterParameterGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CopyDbClusterParameterGroupRequest =
      zio.aws.rds.model.CopyDbClusterParameterGroupRequest(
        sourceDBClusterParameterGroupIdentifier,
        targetDBClusterParameterGroupIdentifier,
        targetDBClusterParameterGroupDescription,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def sourceDBClusterParameterGroupIdentifier: String
    def targetDBClusterParameterGroupIdentifier: String
    def targetDBClusterParameterGroupDescription: String
    def tags: scala.Option[List[zio.aws.rds.model.Tag.ReadOnly]]
    def getSourceDBClusterParameterGroupIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(sourceDBClusterParameterGroupIdentifier)
    def getTargetDBClusterParameterGroupIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(targetDBClusterParameterGroupIdentifier)
    def getTargetDBClusterParameterGroupDescription: ZIO[Any, Nothing, String] =
      ZIO.succeed(targetDBClusterParameterGroupDescription)
    def getTags: ZIO[Any, AwsError, List[zio.aws.rds.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
  ) extends zio.aws.rds.model.CopyDbClusterParameterGroupRequest.ReadOnly {
    override val sourceDBClusterParameterGroupIdentifier: String =
      impl.sourceDBClusterParameterGroupIdentifier(): String
    override val targetDBClusterParameterGroupIdentifier: String =
      impl.targetDBClusterParameterGroupIdentifier(): String
    override val targetDBClusterParameterGroupDescription: String =
      impl.targetDBClusterParameterGroupDescription(): String
    override val tags: scala.Option[List[zio.aws.rds.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.rds.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
  ): zio.aws.rds.model.CopyDbClusterParameterGroupRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.169.1-sources.jar: zio/aws/rds/model/CopyDbClusterParameterGroupRequest.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CopyDbClusterParameterGroupRequest(
    sourceDBClusterParameterGroupIdentifier: String,
    targetDBClusterParameterGroupIdentifier: String,
    targetDBClusterParameterGroupDescription: String,
    tags: Optional[Iterable[zio.aws.rds.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest = {
    import CopyDbClusterParameterGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
      .builder()
      .sourceDBClusterParameterGroupIdentifier(
        sourceDBClusterParameterGroupIdentifier: java.lang.String
      )
      .targetDBClusterParameterGroupIdentifier(
        targetDBClusterParameterGroupIdentifier: java.lang.String
      )
      .targetDBClusterParameterGroupDescription(
        targetDBClusterParameterGroupDescription: java.lang.String
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.CopyDbClusterParameterGroupRequest.ReadOnly =
    zio.aws.rds.model.CopyDbClusterParameterGroupRequest.wrap(buildAwsValue())
}
object CopyDbClusterParameterGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CopyDbClusterParameterGroupRequest =
      zio.aws.rds.model.CopyDbClusterParameterGroupRequest(
        sourceDBClusterParameterGroupIdentifier,
        targetDBClusterParameterGroupIdentifier,
        targetDBClusterParameterGroupDescription,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def sourceDBClusterParameterGroupIdentifier: String
    def targetDBClusterParameterGroupIdentifier: String
    def targetDBClusterParameterGroupDescription: String
    def tags: Optional[List[zio.aws.rds.model.Tag.ReadOnly]]
    def getSourceDBClusterParameterGroupIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(sourceDBClusterParameterGroupIdentifier)
    def getTargetDBClusterParameterGroupIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(targetDBClusterParameterGroupIdentifier)
    def getTargetDBClusterParameterGroupDescription: ZIO[Any, Nothing, String] =
      ZIO.succeed(targetDBClusterParameterGroupDescription)
    def getTags: ZIO[Any, AwsError, List[zio.aws.rds.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
  ) extends zio.aws.rds.model.CopyDbClusterParameterGroupRequest.ReadOnly {
    override val sourceDBClusterParameterGroupIdentifier: String =
      impl.sourceDBClusterParameterGroupIdentifier(): String
    override val targetDBClusterParameterGroupIdentifier: String =
      impl.targetDBClusterParameterGroupIdentifier(): String
    override val targetDBClusterParameterGroupDescription: String =
      impl.targetDBClusterParameterGroupDescription(): String
    override val tags: Optional[List[zio.aws.rds.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.rds.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CopyDbClusterParameterGroupRequest
  ): zio.aws.rds.model.CopyDbClusterParameterGroupRequest.ReadOnly =
    new Wrapper(impl)
}
